{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Diff.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/diff.xml and 'make bootstrap'.
module Skylighting.Syntax.Diff (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Diff.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdiff.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQAdded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQAdded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAttrFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAttrFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAttrFile_File\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAttrFile_File\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAttrFile_RFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAttrFile_RFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrHeader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrHeader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAttrHeader_Chunk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAttrHeader_Chunk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQChunk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNAttrHeader_ChunkInFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNAttrHeader_ChunkInFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vChunkInFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChangedNew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChangedNew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChangedOld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChangedOld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQChunk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQChunk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindDiff\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH@@\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL!\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChangedOld\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vChunkInFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vChunkInFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindDiff\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH@@\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIndex:\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrNormal\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+(====|\\*\\*\\*|\\-\\-\\-|diff|Only in [^:]*:).*$\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL!\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChangedOld\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindDiff\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH@@\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNAttrHeader_ChunkInFile\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNAttrHeader_ChunkInFile\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\*+$\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRChunkInFile\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+(====|\\*\\*\\*|\\-\\-\\-|diff|Only in [^:]*:).*$\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL!\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChangedOld\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX---\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAttrFile\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX+++\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrHeader\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX+>\DC2\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQAdded\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX-<\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRemoved\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\SOH@@\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAttrHeader_Chunk\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAttrHeader_Chunk\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\*+$\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRChunk\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Only in [^:]*:.*$\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdiff\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAttrFile_RFile\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT====\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAttrFile\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX***\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAttrFile_File\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX---\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAttrFile_File\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindDiff\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChangedOld\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRChunk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRChunk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\*\\*\\* .* \\*\\*\\*\\*$\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\-\\-\\- .* \\-\\-\\-\\-$\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRChunkNew\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQChunk\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRChunkInFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRChunkInFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\*\\*\\* .* \\*\\*\\*\\*$\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\-\\-\\- .* \\-\\-\\-\\-$\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRChunkInFileNew\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vChunkInFile\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRChunkInFileNew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRChunkInFileNew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SOH@@\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+(====|\\*\\*\\*|\\-\\-\\-|diff|Only in [^:]*:).*$\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL!\DC2\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChangedNew\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindDiff\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRChunkNew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRChunkNew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SOH@@\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL!\DC2\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChangedNew\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindDiff\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK(diff|Only in [^:]*:)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+(====|\\*\\*\\*|\\-\\-\\-|diff|Only in [^:]*:).*$\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\*+$\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRChunkInFile\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFile\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAttrNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRemoved\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRemoved\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.diff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*patch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.rej\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
